/*!
 * Copyright Adaptavist 2025 (c) All rights reserved
 */
export interface S3HeadObject {
    /**
     * Specifies whether the object retrieved was (true) or was not (false) a Delete Marker. If false, this response header does not appear in the response. This functionality is not supported for directory buckets.
     */
    deleteMarker?: boolean;
    /**
     * Indicates that a range of bytes was specified.
     */
    acceptRanges?: string;
    /**
     * If the object expiration is configured (see PutBucketLifecycleConfiguration), the response includes this header. It includes the expiry-date and rule-id key-value pairs providing object expiration information. The value of the rule-id is URL-encoded. Object expiration information is not returned in directory buckets and this header returns the value "NotImplemented" in all responses for directory buckets.
     */
    expiration?: string;
    /**
     * If the object is an archived object (an object whose storage class is GLACIER), the response includes this header if either the archive restoration is in progress (see RestoreObject or an archive copy is already restored.

    If an archive copy is already restored, the header value indicates when Amazon S3 is scheduled to delete the object copy. For example:

    x-amz-restore: ongoing-request="false", expiry-date="Fri, 21 Dec 2012 00:00:00 GMT"

    If the object restoration is in progress, the header returns the value ongoing-request="true".

     * This functionality is not supported for directory buckets. Directory buckets only support EXPRESS_ONEZONE (the S3 Express One Zone storage class) in Availability Zones and ONEZONE_IA (the S3 One Zone-Infrequent Access storage class) in Dedicated Local Zones.
     */
    restore?: string;
    /**
     * The archive state of the head object. This functionality is not supported for directory buckets.
     */
    archiveStatus?: 'ARCHIVE_ACCESS' | 'DEEP_ARCHIVE_ACCESS';
    /**
     * Date and time when the object was last modified.
     */
    lastModified?: string;
    /**
     * Size of the body in bytes.
     */
    contentLength?: number;
    /**
     * The Base64 encoded, 32-bit CRC32 checksum of the object. This checksum is only be present if the checksum was uploaded with the object. When you use an API operation on an object that was uploaded using multipart uploads, this value may not be a direct checksum value of the full object. Instead, it's a calculation based on the checksum values of each individual part.
     */
    checksumCRC32?: string;
    /**
     * The Base64 encoded, 32-bit CRC32C checksum of the object. This checksum is only present if the checksum was uploaded with the object. When you use an API operation on an object that was uploaded using multipart uploads, this value may not be a direct checksum value of the full object. Instead, it's a calculation based on the checksum values of each individual part.
     */
    checksumCRC32C?: string;
    /**
     * The Base64 encoded, 64-bit CRC64NVME checksum of the object.
     */
    checksumCRC64NVME?: string;
    /**
     * The Base64 encoded, 160-bit SHA1 digest of the object. This will only be present if the object was uploaded with the object. When you use the API operation on an object that was uploaded using multipart uploads, this value may not be a direct checksum value of the full object. Instead, it's a calculation based on the checksum values of each individual part.
     */
    checksumSHA1?: string;
    /**
     * The Base64 encoded, 256-bit SHA256 digest of the object. This will only be present if the object was uploaded with the object. When you use an API operation on an object that was uploaded using multipart uploads, this value may not be a direct checksum value of the full object. Instead, it's a calculation based on the checksum values of each individual part.
     */
    checksumSHA256?: string;
    /**
     * The checksum type, which determines how part-level checksums are combined to create an object-level checksum for multipart objects. You can use this header response to verify that the checksum type that is received is the same checksum type that was specified in CreateMultipartUpload request.
     */
    checksumType?: 'COMPOSITE' | 'FULL_OBJECT';
    /**
     * An entity tag (ETag) is an opaque identifier assigned by a web server to a specific version of a resource found at a URL.
     */
    eTag?: string;
    /**
     * This is set to the number of metadata entries not returned in x-amz-meta headers. This can happen if you create metadata using an API like SOAP that supports more flexible metadata than the REST API. For example, using SOAP, you can create metadata whose values are not legal HTTP headers. This functionality is not supported for directory buckets.
     */
    missingMeta?: number;
    /**
     * Version ID of the object. This functionality is not supported for directory buckets.
     */
    versionId?: string;
    /**
     * Specifies caching behavior along the request/reply chain.
     */
    cacheControl?: string;
    /**
     * Specifies presentational information for the object
     */
    contentDisposition?: string;
    /**
     * Indicates what content encodings have been applied to the object and thus what decoding mechanisms must be applied to obtain the media-type referenced by the Content-Type header field.
     */
    contentEncoding?: string;
    /**
     * The language the content is in.
     */
    contentLanguage?: string;
    /**
     * A standard MIME type describing the format of the object data.
     */
    contentType?: string;
    /**
     * The portion of the object returned in the response for a GET request.
     */
    contentRange?: string;
    /**
     * The date and time at which the object is no longer cacheable.
     */
    expires?: string;
    /**
     * If the bucket is configured as a website, redirects requests for this object to another object in the same bucket or to an external URL. Amazon S3 stores the value of this header in the object metadata. This functionality is not supported for directory buckets.
     */
    websiteRedirectLocation?: string;
    /**
     * The server-side encryption algorithm used when you store this object in Amazon S3 (for example, AES256, aws:kms, aws:kms:dsse).
     */
    serverSideEncryption?: 'AES256' | 'aws:kms' | 'aws:kms:dsse';
    /**
     * If server-side encryption with a customer-provided encryption key was requested, the response will include this header to confirm the encryption algorithm that's used. This functionality is not supported for directory buckets.
     */
    sseCustomerAlgorithm?: string;
    /**
     * If server-side encryption with a customer-provided encryption key was requested, the response will include this header to provide the round-trip message integrity verification of the customer-provided encryption key. This functionality is not supported for directory buckets.
     */
    sseCustomerKeyMD5?: string;
    /**
     * If present, indicates the ID of the KMS key that was used for object encryption.
     */
    sseKMSKeyId?: string;
    /**
     * Indicates whether the object uses an S3 Bucket Key for server-side encryption with AWS Key Management Service (AWS KMS) keys (SSE-KMS).
     */
    bucketKeyEnabled?: boolean;
    /**
     * Provides storage class information of the object. Amazon S3 returns this header for all objects except for S3 Standard storage class objects.
     
     * Directory buckets - Directory buckets only support EXPRESS_ONEZONE (the S3 Express One Zone storage class) in Availability Zones and ONEZONE_IA (the S3 One Zone-Infrequent Access storage class) in Dedicated Local Zones.
     */
    storageClass?: 'STANDARD' | 'REDUCED_REDUNDANCY' | 'STANDARD_IA' | 'ONEZONE_IA' | 'INTELLIGENT_TIERING' | 'GLACIER' | 'DEEP_ARCHIVE' | 'OUTPOSTS' | 'GLACIER_IR' | 'SNOW' | 'EXPRESS_ONEZONE';
    /**
     * If present, indicates that the requester was successfully charged for the request. This functionality is not supported for directory buckets.
     */
    requestCharged?: 'requester';
    /**
     * Amazon S3 can return this header if your request involves a bucket that is either a source or a destination in a replication rule.

    In replication, you have a source bucket on which you configure replication and destination bucket or buckets where Amazon S3 stores object replicas. When you request an object (GetObject) or object metadata (HeadObject) from these buckets, Amazon S3 will return the x-amz-replication-status header in the response as follows:

    ** If requesting an object from the source bucket, Amazon S3 will return the x-amz-replication-status header if the object in your request is eligible for replication.
    For example, suppose that in your replication configuration, you specify object prefix TaxDocs requesting Amazon S3 to replicate objects with key prefix TaxDocs. Any objects you upload with this key name prefix, for example TaxDocs/document1.pdf, are eligible for replication. For any object request with this key name prefix, Amazon S3 will return the x-amz-replication-status header with value PENDING, COMPLETED or FAILED indicating object replication status.

    ** If requesting an object from a destination bucket, Amazon S3 will return the x-amz-replication-status header with value REPLICA if the object in your request is a replica that Amazon S3 created and there is no replica modification replication in progress.

    ** When replicating objects to multiple destination buckets, the x-amz-replication-status header acts differently. The header of the source object will only return a value of COMPLETED when replication is successful to all destinations. The header will remain at value PENDING until replication has completed for all destinations. If one or more destinations fails replication the header will return FAILED.
     */
    replicationStatus?: 'COMPLETE' | 'PENDING' | 'FAILED' | 'REPLICA' | 'COMPLETED';
    /**
     * The count of parts this object has. This value is only returned if you specify partNumber in your request and the object was uploaded as a multipart upload.
     */
    partsCount?: number;
    /**
     * The Object Lock mode, if any, that's in effect for this object. This header is only returned if the requester has the s3:GetObjectRetention permission. This functionality is not supported for directory buckets.
     */
    objectLockMode?: 'GOVERNANCE' | 'COMPLIANCE';
    /**
     * The date and time when the Object Lock retention period expires. This header is only returned if the requester has the s3:GetObjectRetention permission. This functionality is not supported for directory buckets.
     */
    objectLockRetainUntilDate?: string;
    /**
     * Specifies whether a legal hold is in effect for this object. This header is only returned if the requester has the s3:GetObjectLegalHold permission. This header is not returned if the specified version of this object has never had a legal hold applied. This functionality is not supported for directory buckets.
     */
    objectLockLegalHoldStatus?: 'ON' | 'OFF';
}
//# sourceMappingURL=S3HeadObject.d.ts.map