import { Response, BaseApiCore, constructHeaders, constructUrl, Request, executeHttpCall } from '@managed-api/commons-core';
import { errorStrategyBuilderConstructor, customErrorHandlers } from './errorStrategy';
import { errorMessageBuilder, encodeRFC3986URI } from './common';
import { j2xParser, parse } from 'fast-xml-parser';
;
export class AWSApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.S3 = new S3Group(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.S3);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...(_a = this.options) !== null && _a !== void 0 ? _a : {},
            errorStrategy
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(S3) {
        this.S3 = S3;
    }
    /**
     * Creates a copy of an object that is already stored in Amazon S3.
     * Alternative usage: S3.Object.copyObject
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_CopyObject.html
     * @param options Request options.
     */
    async copyS3Object(options) {
        return this.S3.Object.copyObject(options);
    }
    /**
     * Removes an object from a bucket.
     * Alternative usage: S3.Object.deleteObject
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html
     * @param options Request options.
     */
    async deleteS3Object(options) {
        return this.S3.Object.deleteObject(options);
    }
    /**
     * Retrieves an object from Amazon S3.
     * Alternative usage: S3.Object.getObject
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html
     * @param options Request options.
     */
    async getS3Object(options) {
        return this.S3.Object.getObject(options);
    }
    /**
     * The HEAD operation retrieves metadata from an object without returning the object itself. This operation is useful if you're interested only in an object's metadata.
     * Alternative usage: S3.Object.getObjectHead
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_HeadObject.html
     * @param options Request options.
     */
    async getS3ObjectHead(options) {
        return this.S3.Object.getObjectHead(options);
    }
    /**
     * Returns some or all (up to 1,000) of the objects in a bucket with each request. You can use the request parameters as selection criteria to return a subset of the objects in a bucket. A 200 OK response can contain valid or invalid XML. Make sure to design your application to parse the contents of the response and handle it appropriately.
     * Alternative usage: S3.Object.getObjectsV2
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjectsV2.html
     * @param options Request options.
     */
    async getS3ObjectsV2(options) {
        return this.S3.Object.getObjectsV2(options);
    }
    /**
     * Returns metadata about all versions of the objects in a bucket. You can also use request parameters as selection criteria to return metadata about a subset of all the object versions.
     * Alternative usage: S3.Object.getObjectVersions
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjectVersions.html
     * @param options Request options.
     */
    async getS3ObjectVersions(options) {
        return this.S3.Object.getObjectVersions(options);
    }
    /**
     * Adds an object to a bucket.
     * Alternative usage: S3.Object.putObject
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html
     * @param options Request options.
     */
    async putS3Object(options) {
        return this.S3.Object.putObject(options);
    }
    /**
     * Creates a new S3 bucket. To create a bucket, you must set up Amazon S3 and have a valid AWS Access Key ID to authenticate requests. Anonymous requests are never allowed to create buckets. By creating the bucket, you become the bucket owner.
     * Alternative usage: S3.Bucket.createBucket
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html
     * @param options Request options.
     */
    async createS3Bucket(options) {
        return this.S3.Bucket.createBucket(options);
    }
    /**
     * Deletes the S3 bucket. All objects (including all object versions and delete markers) in the bucket must be deleted before the bucket itself can be deleted.
     * Alternative usage: S3.Bucket.deleteBucket
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucket.html
     * @param options Request options.
     */
    async deleteS3Bucket(options) {
        return this.S3.Bucket.deleteBucket(options);
    }
    /**
     * You can use this operation to determine if a bucket exists and if you have permission to access it. The action returns a 200 OK if the bucket exists and you have permission to access it.
     * Alternative usage: S3.Bucket.getBucketHead
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_HeadBucket.html
     * @param options Request options.
     */
    async getS3BucketHead(options) {
        return this.S3.Bucket.getBucketHead(options);
    }
    /**
     * Returns a list of all buckets owned by the authenticated sender of the request. To grant IAM permission to use this operation, you must add the s3:ListAllMyBuckets policy action.
     * Alternative usage: S3.Bucket.getBuckets
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBuckets.html
     * @param options Request options.
     */
    async getS3Buckets(options) {
        return this.S3.Bucket.getBuckets(options);
    }
}
class S3Group {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Object = new S3ObjectGroup(implementation, this.getGlobalErrorStrategy);
        this.Bucket = new S3BucketGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class S3ObjectGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Creates a copy of an object that is already stored in Amazon S3.
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_CopyObject.html
     * @param options Request options.
     */
    async copyObject(options) {
        const { headers, errorStrategy, bucket, region, key, copySource, ...params } = options;
        const headerParams = {
            'x-amz-copy-source': encodeURIComponent(copySource),
            'x-amz-acl': params.acl,
            'Cache-Control': params.cacheControl,
            'x-amz-checksum-algorithm': params.checksumAlgorithm,
            'Content-Disposition': params.contentDisposition,
            'Content-Encoding': params.contentEncoding,
            'Content-Language': params.contentLanguage,
            'Content-Type': params.contentType,
            'x-amz-copy-source-if-match': params.copySourceIfMatch,
            'x-amz-copy-source-if-modified-since': params.copySourceIfModifiedSince,
            'x-amz-copy-source-if-none-match': params.copySourceIfNoneMatch,
            'x-amz-copy-source-if-unmodified-since': params.copySourceIfUnmodifiedSince,
            Expires: params.expires,
            'x-amz-grant-full-control': params.grantFullControl,
            'x-amz-grant-read': params.grantRead,
            'x-amz-grant-read-acp': params.grantReadACP,
            'x-amz-grant-write-acp': params.grantWriteACP,
            'x-amz-metadata-directive': params.metadataDirective,
            'x-amz-tagging-directive': params.taggingDirective,
            'x-amz-server-side-encryption': params.serverSideEncryption,
            'x-amz-storage-class': params.storageClass,
            'x-amz-website-redirect-location': params.websiteRedirectLocation,
            'x-amz-server-side-encryption-customer-algorithm': params.sseCustomerAlgorithm,
            'x-amz-server-side-encryption-customer-key': params.sseCustomerKey,
            'x-amz-server-side-encryption-customer-key-MD5': params.sseCustomerKeyMD5,
            'x-amz-server-side-encryption-aws-kms-key-id': params.sseKMSKeyId,
            'x-amz-server-side-encryption-context': params.sseKMSEncryptionContext,
            'x-amz-server-side-encryption-bucket-key-enabled': params.ssebucketKeyEnabled,
            'x-amz-copy-source-server-side-encryption-customer-algorithm': params.copySourceSSECustomerAlgorithm,
            'x-amz-copy-source-server-side-encryption-customer-key': params.copySourceSSECustomerKey,
            'x-amz-copy-source-server-side-encryption-customer-key-MD5': params.copySourceSSECustomerKeyMD5,
            'x-amz-request-payer': params.requestPayer,
            'x-amz-tagging': params.tagging,
            'x-amz-object-lock-mode': params.objectLockMode,
            'x-amz-object-lock-retain-until-date': params.objectLockRetainUntilDate,
            'x-amz-object-lock-legal-hold': params.objectLockLegalHoldStatus,
            'x-amz-expected-bucket-owner': params.expectedBucketOwner,
            'x-amz-source-expected-bucket-owner': params.expectedSourceBucketOwner,
        };
        const requestHeaders = Object.entries(headerParams).reduce((acc, [hdr, value]) => {
            if (value) {
                acc[hdr] = value.toString();
            }
            return acc;
        }, {});
        const request = new Request('PUT', `https://${encodeURIComponent(bucket)}.s3.${encodeURIComponent(region)}.amazonaws.com/${encodeRFC3986URI(key)}`, constructHeaders(undefined, { ...headers, ...requestHeaders }));
        request.setBufferImplementation(this.implementation);
        const parseResponse = async (res) => {
            const responseText = await res.text();
            const parsedResponse = parse(responseText, { tagValueProcessor: (tagValue, tagName) => tagName === 'ETag' ? tagValue.substring(1, tagValue.length - 2) : tagValue }, true);
            return parsedResponse.CopyObjectResult;
        };
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, parseResponse);
    }
    /**
     * Removes an object from a bucket.
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html
     * @param options Request options.
     */
    async deleteObject(options) {
        const { headers, errorStrategy, bucket, region, key, versionId, ...params } = options;
        const headerParams = {
            'x-amz-mfa': params.mfa,
            'x-amz-request-payer': params.requestPayer,
            'x-amz-bypass-governance-retention': params.bypassGovernanceRetention,
            'x-amz-expected-bucket-owner': params.expectedBucketOwner,
            'If-Match': params.ifMatch,
            'x-amz-if-match-last-modified-time': params.ifMatchLastModifiedTime,
            'x-amz-if-match-size': params.ifMatchSize,
        };
        const requestUrl = `https://${encodeURIComponent(bucket)}.s3.${encodeURIComponent(region)}.amazonaws.com/${encodeRFC3986URI(key)}`;
        const requestHeaders = Object.entries(headerParams).reduce((acc, [hdr, value]) => {
            if (value) {
                acc[hdr] = value.toString();
            }
            return acc;
        }, {});
        const request = new Request('DELETE', constructUrl(requestUrl, { versionId }), constructHeaders(undefined, { ...headers, ...requestHeaders }));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Retrieves an object from Amazon S3.
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html
     * @param options Request options.
     */
    async getObject(options) {
        const queryParams = {
            partNumber: options.partNumber,
            'response-cache-control': options.responseCacheControl,
            'response-content-disposition': options.responseContentDisposition,
            'response-content-encoding': options.responseContentEncoding,
            'response-content-language': options.responseContentEncoding,
            'response-content-type': options.responseContentType,
            'response-expires': options.responseExpires,
            versionId: options.versionId,
        };
        const headerParams = {
            'If-Match': options.ifMatch,
            'If-Modified-Since': options.ifModifiedSince,
            'If-None-Match': options.ifNoneMatch,
            'If-Unmodified-Since': options.ifUnmodifiedSince,
            Range: options.range,
            'x-amz-server-side-encryption-customer-algorithm': options.ssCustomerAlgorithm,
            'x-amz-server-side-encryption-customer-key': options.sseCustomerKey,
            'x-amz-server-side-encryption-customer-key-MD5': options.sseCustomerKeyMD5,
            'x-amz-request-payer': options.requestPayer,
            'x-amz-expected-bucket-owner': options.expectedBucketOwner,
            'x-amz-checksum-mode': options.checksumMode,
        };
        const { headers, errorStrategy, bucket, region, key } = options;
        const requestUrl = `https://${encodeURIComponent(bucket)}.s3.${encodeURIComponent(region)}.amazonaws.com/${encodeRFC3986URI(key)}`;
        const requestHeaders = Object.entries(headerParams).reduce((acc, [hdr, value]) => {
            if (value) {
                acc[hdr] = value.toString();
            }
            return acc;
        }, {});
        const request = new Request('GET', constructUrl(requestUrl, queryParams), constructHeaders(undefined, { ...headers, ...requestHeaders }));
        request.setBufferImplementation(this.implementation);
        const parseResponse = async (res) => {
            return await res.arrayBuffer();
        };
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, parseResponse);
    }
    /**
     * The HEAD operation retrieves metadata from an object without returning the object itself. This operation is useful if you're interested only in an object's metadata.
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_HeadObject.html
     * @param options Request options.
     */
    async getObjectHead(options) {
        const queryParams = {
            partNumber: options.partNumber,
            'response-cache-control': options.responseCacheControl,
            'response-content-disposition': options.responseContentDisposition,
            'response-content-encoding': options.responseContentEncoding,
            'response-content-language': options.responseContentLanguage,
            'response-content-type': options.responseContentType,
            'response-expires': options.responseExpires,
            versionId: options.versionId,
        };
        const headerParams = {
            'If-Match': options.ifMatch,
            'If-Modified-Since': options.ifModifiedSince,
            'If-None-Match': options.ifNoneMatch,
            'If-Unmodified-Since': options.ifUnmodifiedSince,
            Range: options.range,
            'x-amz-server-side-encryption-customer-algorithm': options.sseCustomerAlgorithm,
            'x-amz-server-side-encryption-customer-key': options.sseCustomerKey,
            'x-amz-server-side-encryption-customer-key-MD5': options.sseCustomerKeyMD5,
            'x-amz-request-payer': options.requestPayer,
            'x-amz-expected-bucket-owner': options.expectedBucketOwner,
            'x-amz-checksum-mode': options.checksumMode,
        };
        const { headers, errorStrategy, bucket, region, key } = options;
        const requestUrl = `https://${encodeURIComponent(bucket)}.s3.${encodeURIComponent(region)}.amazonaws.com/${encodeRFC3986URI(key)}`;
        const requestHeaders = Object.entries(headerParams).reduce((acc, [hdr, value]) => {
            if (value) {
                acc[hdr] = value.toString();
            }
            return acc;
        }, {});
        const request = new Request('HEAD', constructUrl(requestUrl, queryParams), constructHeaders(undefined, { ...headers, ...requestHeaders }));
        request.setBufferImplementation(this.implementation);
        const parseResponse = async (res) => {
            var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u, _v, _w, _x, _y, _z, _0, _1, _2, _3, _4, _5, _6;
            const deleteMarker = res.headers.get('x-amz-delete-marker');
            const contentLength = res.headers.get('content-length');
            const missingMeta = res.headers.get('x-amz-missing-meta');
            const bucketKeyEnabled = res.headers.get('x-amz-server-side-encryption-bucket-key-enabled');
            const partsCount = res.headers.get('x-amz-mp-parts-count');
            const responseHeaderParams = {
                deleteMarker: deleteMarker ? deleteMarker === 'true' : undefined,
                acceptRanges: (_a = res.headers.get('accept-ranges')) !== null && _a !== void 0 ? _a : undefined,
                expiration: (_b = res.headers.get('x-amz-expiration')) !== null && _b !== void 0 ? _b : undefined,
                restore: (_c = res.headers.get('x-amz-restore')) !== null && _c !== void 0 ? _c : undefined,
                archiveStatus: ((_d = res.headers.get('x-amz-archive-status')) !== null && _d !== void 0 ? _d : undefined),
                lastModified: (_e = res.headers.get('last-modified')) !== null && _e !== void 0 ? _e : undefined,
                contentLength: contentLength ? +contentLength : undefined,
                checksumCRC32: (_f = res.headers.get('x-amz-checksum-crc32')) !== null && _f !== void 0 ? _f : undefined,
                checksumCRC32C: (_g = res.headers.get('x-amz-checksum-crc32c')) !== null && _g !== void 0 ? _g : undefined,
                checksumCRC64NVME: (_h = res.headers.get('x-amz-checksum-crc64nvme')) !== null && _h !== void 0 ? _h : undefined,
                checksumSHA1: (_j = res.headers.get('x-amz-checksum-sha1')) !== null && _j !== void 0 ? _j : undefined,
                checksumSHA256: (_k = res.headers.get('x-amz-checksum-sha256')) !== null && _k !== void 0 ? _k : undefined,
                checksumType: ((_l = res.headers.get('x-amz-checksum-type')) !== null && _l !== void 0 ? _l : undefined),
                eTag: (_m = res.headers.get('etag')) !== null && _m !== void 0 ? _m : undefined,
                missingMeta: missingMeta ? +missingMeta : undefined,
                versionId: (_o = res.headers.get('x-amz-version-id')) !== null && _o !== void 0 ? _o : undefined,
                cacheControl: (_p = res.headers.get('cache-control')) !== null && _p !== void 0 ? _p : undefined,
                contentDisposition: (_q = res.headers.get('content-disposition')) !== null && _q !== void 0 ? _q : undefined,
                contentEncoding: (_r = res.headers.get('content-encoding')) !== null && _r !== void 0 ? _r : undefined,
                contentLanguage: (_s = res.headers.get('content-language')) !== null && _s !== void 0 ? _s : undefined,
                contentType: (_t = res.headers.get('content-type')) !== null && _t !== void 0 ? _t : undefined,
                contentRange: (_u = res.headers.get('content-range')) !== null && _u !== void 0 ? _u : undefined,
                expires: (_v = res.headers.get('expires')) !== null && _v !== void 0 ? _v : undefined,
                websiteRedirectLocation: (_w = res.headers.get('x-amz-website-redirect-location')) !== null && _w !== void 0 ? _w : undefined,
                serverSideEncryption: ((_x = res.headers.get('x-amz-server-side-encryption')) !== null && _x !== void 0 ? _x : undefined),
                sseCustomerAlgorithm: (_y = res.headers.get('x-amz-server-side-encryption-customer-algorithm')) !== null && _y !== void 0 ? _y : undefined,
                sseCustomerKeyMD5: (_z = res.headers.get('x-amz-server-side-encryption-customer-key-MD5')) !== null && _z !== void 0 ? _z : undefined,
                sseKMSKeyId: (_0 = res.headers.get('x-amz-server-side-encryption-aws-kms-key-id')) !== null && _0 !== void 0 ? _0 : undefined,
                bucketKeyEnabled: bucketKeyEnabled ? bucketKeyEnabled === 'true' : undefined,
                storageClass: ((_1 = res.headers.get('x-amz-storage-class')) !== null && _1 !== void 0 ? _1 : undefined),
                requestCharged: ((_2 = res.headers.get('x-amz-request-charged')) !== null && _2 !== void 0 ? _2 : undefined),
                replicationStatus: ((_3 = res.headers.get('x-amz-replication-status')) !== null && _3 !== void 0 ? _3 : undefined),
                partsCount: partsCount ? +partsCount : undefined,
                objectLockMode: ((_4 = res.headers.get('x-amz-object-lock-mode')) !== null && _4 !== void 0 ? _4 : undefined),
                objectLockRetainUntilDate: (_5 = res.headers.get('x-amz-object-lock-retain-until-date')) !== null && _5 !== void 0 ? _5 : undefined,
                objectLockLegalHoldStatus: ((_6 = res.headers.get('x-amz-object-lock-legal-hold')) !== null && _6 !== void 0 ? _6 : undefined),
            };
            return responseHeaderParams;
        };
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, parseResponse);
    }
    /**
     * Returns some or all (up to 1,000) of the objects in a bucket with each request. You can use the request parameters as selection criteria to return a subset of the objects in a bucket. A 200 OK response can contain valid or invalid XML. Make sure to design your application to parse the contents of the response and handle it appropriately.
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjectsV2.html
     * @param options Request options.
     */
    async getObjectsV2(options) {
        const queryParams = {
            'list-type': 2,
            delimiter: options.delimiter,
            'continuation-token': options.continuationToken,
            'encoding-type': options.encodingType,
            'fetch-owner': options.fetchOwner,
            'max-keys': options.maxKeys,
            'start-after': options.startAfter,
            prefix: options.prefix,
        };
        const headerParams = {
            'x-amz-request-payer': options.requestPayer,
            'x-amz-expected-bucket-owner': options.expectedBucketOwner,
            'x-amz-optional-object-attributes': options.optionalObjectAttributes,
        };
        const { headers, errorStrategy, bucket, region } = options;
        const requestHeaders = Object.entries(headerParams).reduce((acc, [hdr, value]) => {
            if (value) {
                acc[hdr] = value.toString();
            }
            return acc;
        }, {});
        const request = new Request('GET', constructUrl(`https://${encodeURIComponent(bucket)}.s3.${encodeURIComponent(region)}.amazonaws.com`, queryParams), constructHeaders(undefined, { ...headers, ...requestHeaders }));
        request.setBufferImplementation(this.implementation);
        const parseResponse = async (res) => {
            const responseText = await res.text();
            const parsedResponse = parse(responseText, { arrayMode: (tagName) => tagName === 'CommonPrefixes' || tagName === 'Contents' || tagName === 'ChecksumAlgorithm' }, true);
            return parsedResponse.ListBucketResult;
        };
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, parseResponse);
    }
    /**
     * Returns metadata about all versions of the objects in a bucket. You can also use request parameters as selection criteria to return metadata about a subset of all the object versions.
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjectVersions.html
     * @param options Request options.
     */
    async getObjectVersions(options) {
        const queryParams = {
            delimiter: options.delimiter,
            'encoding-type': options.encodingType,
            'key-marker': options.keyMarker,
            'max-keys': options.maxKeys,
            prefix: options.prefix,
            'version-id-marker': options.versionIdMarker,
        };
        const headerParams = {
            'x-amz-expected-bucket-owner': options.expectedBucketOwner,
            'x-amz-optional-object-attributes': options.optionalObjectAttributes,
            'x-amz-request-payer': options.requestPayer,
        };
        const { headers, errorStrategy, bucket, region } = options;
        const requestHeaders = Object.entries(headerParams).reduce((acc, [hdr, value]) => {
            if (value) {
                acc[hdr] = value.toString();
            }
            return acc;
        }, {});
        const requestUrl = constructUrl(`https://${encodeURIComponent(bucket)}.s3.${encodeURIComponent(region)}.amazonaws.com/?versions`, queryParams).replace('/?versions?', '/?versions&');
        const request = new Request('GET', requestUrl, constructHeaders(undefined, { ...headers, ...requestHeaders }));
        request.setBufferImplementation(this.implementation);
        const parseResponse = async (res) => {
            const responseText = await res.text();
            const parsedResponse = parse(responseText, { arrayMode: (tagName) => tagName === 'CommonPrefixes' || tagName === 'Contents' || tagName === 'ChecksumAlgorithm' }, true);
            return parsedResponse.ListVersionsResult;
        };
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, parseResponse);
    }
    /**
     * Adds an object to a bucket.
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html
     * @param options Request options.
     */
    async putObject(options) {
        const { headers, errorStrategy, bucket, region, key, body, ...params } = options;
        const headerParams = {
            'x-amz-acl': params.acl,
            'Cache-Control': params.cacheControl,
            'Content-Disposition': params.contentDisposition,
            'Content-Encoding': params.contentEncoding,
            'Content-Language': params.contentLanguage,
            'Content-Length': params.contentLength,
            'Content-MD5': params.contentMD5,
            'Content-Type': params.contentType,
            'x-amz-sdk-checksum-algorithm': params.checksumAlgorithm,
            'x-amz-checksum-crc32': params.checksumCRC32,
            'x-amz-checksum-crc32c': params.checksumCRC32C,
            'x-amz-checksum-crc64nvme': params.checksumCRC64NVME,
            'x-amz-checksum-sha1': params.checksumSHA1,
            'x-amz-checksum-sha256': params.checksumSHA256,
            Expires: params.expires,
            'If-Match': params.ifMatch,
            'If-None-Match': params.ifNoneMatch,
            'x-amz-grant-full-control': params.grantFullControl,
            'x-amz-grant-read': params.grantRead,
            'x-amz-grant-read-acp': params.grantReadACP,
            'x-amz-grant-write-acp': params.grantWriteACP,
            'x-amz-write-offset-bytes': params.writeOffsetBytes,
            'x-amz-server-side-encryption': params.serverSideEncryption,
            'x-amz-storage-class': params.storageClass,
            'x-amz-website-redirect-location': params.websiteRedirectLocation,
            'x-amz-server-side-encryption-customer-algorithm': params.sseCustomerAlgorithm,
            'x-amz-server-side-encryption-customer-key': params.sseCustomerKey,
            'x-amz-server-side-encryption-customer-key-MD5': params.sseCustomerKeyMD5,
            'x-amz-server-side-encryption-aws-kms-key-id': params.sseKMSKeyId,
            'x-amz-server-side-encryption-context': params.sseKMSEncryptionContext,
            'x-amz-server-side-encryption-bucket-key-enabled': params.bucketKeyEnabled,
            'x-amz-request-payer': params.requestPayer,
            'x-amz-tagging': params.tagging,
            'x-amz-object-lock-mode': params.objectLockMode,
            'x-amz-object-lock-retain-until-date': params.objectLockRetainUntilDate,
            'x-amz-object-lock-legal-hold': params.objectLockLegalHoldStatus,
            'x-amz-expected-bucket-owner': params.expectedBucketOwner,
        };
        const requestHeaders = Object.entries(headerParams).reduce((acc, [hdr, value]) => {
            if (value) {
                acc[hdr] = value.toString();
            }
            return acc;
        }, {});
        const request = new Request('PUT', `https://${encodeURIComponent(bucket)}.s3.${encodeURIComponent(region)}.amazonaws.com/${encodeRFC3986URI(key)}`, constructHeaders(body, { 'Content-Type': '*/*', ...headers, ...requestHeaders }), body);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class S3BucketGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Creates a new S3 bucket. To create a bucket, you must set up Amazon S3 and have a valid AWS Access Key ID to authenticate requests. Anonymous requests are never allowed to create buckets. By creating the bucket, you become the bucket owner.
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html
     * @param options Request options.
     */
    async createBucket(options) {
        const { body, headers, errorStrategy, bucket, region, ...params } = options;
        const headerParams = {
            'x-amz-acl': params.acl,
            'x-amz-grant-full-control': params.grantFullControl,
            'x-amz-grant-read': params.grantRead,
            'x-amz-grant-read-acp': params.grantReadACP,
            'x-amz-grant-write': params.grantWrite,
            'x-amz-grant-write-acp': params.grantWriteACP,
            'x-amz-bucket-object-lock-enabled': params.objectLockEnabledForBucket,
            'x-amz-object-ownership': params.objectOwnership,
        };
        const requestHeaders = Object.entries(headerParams).reduce((acc, [hdr, value]) => {
            if (value) {
                acc[hdr] = value.toString();
            }
            return acc;
        }, {});
        const requestBody = body ? new j2xParser({}).parse({ CreateBucketConfiguration: body }) : undefined;
        const request = new Request('PUT', `https://${encodeURIComponent(bucket)}.s3.${encodeURIComponent(region)}.amazonaws.com`, constructHeaders(body, { ...headers, ...requestHeaders }), requestBody);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Deletes the S3 bucket. All objects (including all object versions and delete markers) in the bucket must be deleted before the bucket itself can be deleted.
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucket.html
     * @param options Request options.
     */
    async deleteBucket(options) {
        const { headers, errorStrategy, bucket, region, expectedBucketOwner } = options;
        const headerParams = {
            'x-amz-expected-bucket-owner': expectedBucketOwner,
        };
        const requestHeaders = Object.entries(headerParams).reduce((acc, [hdr, value]) => {
            if (value) {
                acc[hdr] = value.toString();
            }
            return acc;
        }, {});
        const request = new Request('DELETE', `https://${encodeURIComponent(bucket)}.s3.${encodeURIComponent(region)}.amazonaws.com`, constructHeaders(undefined, { ...headers, ...requestHeaders }));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * You can use this operation to determine if a bucket exists and if you have permission to access it. The action returns a 200 OK if the bucket exists and you have permission to access it.
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_HeadBucket.html
     * @param options Request options.
     */
    async getBucketHead(options) {
        const { headers, errorStrategy, bucket, region, expectedBucketOwner } = options;
        const headerParams = {
            'x-amz-expected-bucket-owner': expectedBucketOwner,
        };
        const requestHeaders = Object.entries(headerParams).reduce((acc, [hdr, value]) => {
            if (value) {
                acc[hdr] = value.toString();
            }
            return acc;
        }, {});
        const request = new Request('HEAD', `https://${encodeURIComponent(bucket)}.s3.${encodeURIComponent(region)}.amazonaws.com`, constructHeaders(undefined, { ...headers, ...requestHeaders }));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Returns a list of all buckets owned by the authenticated sender of the request. To grant IAM permission to use this operation, you must add the s3:ListAllMyBuckets policy action.
     * Documentation: https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBuckets.html
     * @param options Request options.
     */
    async getBuckets(options) {
        const { headers, errorStrategy, ...params } = options;
        const queryParams = {
            'bucket-region': params.bucketRegion,
            'continuation-token': params.continuationToken,
            'max-buckets': params.maxBuckets,
            prefix: params.prefix,
        };
        const request = new Request('GET', constructUrl(`https://s3.${encodeURIComponent(queryParams['bucket-region'])}.amazonaws.com`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        const parseResponse = async (res) => {
            var _a;
            const responseText = await res.text();
            const parsedResponse = parse(responseText, { arrayMode: (tagName) => tagName === 'Bucket' }, true);
            return {
                ...parsedResponse.ListAllMyBucketsResult,
                Buckets: (_a = parsedResponse.ListAllMyBucketsResult.Buckets.Bucket) !== null && _a !== void 0 ? _a : [],
            };
        };
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, parseResponse);
    }
}
