/*!
 * Copyright Adaptavist 2025 (c) All rights reserved
 */
import { S3Buckets } from '../../definitions/S3Buckets';
import { ErrorStrategyOption } from '../../errorStrategy';
import { HeadersOption } from '@managed-api/commons-core';
export interface CreatS3BucketRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the bucket to create.
     */
    bucket: string;
    region: string;
    /**
     * The canned ACL to apply to the bucket. This functionality is not supported for directory buckets.
     */
    acl?: 'private' | 'public-read' | 'public-read-write' | 'authenticated-read';
    /**
     * Allows grantee the read, write, read ACP, and write ACP permissions on the bucket. This functionality is not supported for directory buckets.
     */
    grantFullControl?: string;
    /**
     * Allows grantee to list the objects in the bucket. This functionality is not supported for directory buckets.
     */
    grantRead?: string;
    /**
     * Allows grantee to read the bucket ACL. This functionality is not supported for directory buckets.
     */
    grantReadACP?: string;
    /**
     * Allows grantee to create new objects in the bucket. This functionality is not supported for directory buckets.
  
        For the bucket and object owners of existing objects, also allows deletions and overwrites of those objects.
     */
    grantWrite?: string;
    /**
     * Allows grantee to write the ACL for the applicable bucket. This functionality is not supported for directory buckets.
     */
    grantWriteACP?: string;
    /**
     * Specifies whether you want S3 Object Lock to be enabled for the new bucket. This functionality is not supported for directory buckets.
     */
    objectLockEnabledForBucket?: boolean;
    /**
     * The container element for object ownership for a bucket's ownership controls. This functionality is not supported for directory buckets. Directory buckets use the bucket owner enforced setting for S3 Object Ownership.
  
    BucketOwnerPreferred - Objects uploaded to the bucket change ownership to the bucket owner if the objects are uploaded with the bucket-owner-full-control canned ACL.
    
    ObjectWriter - The uploading account will own the object if the object is uploaded with the bucket-owner-full-control canned ACL.
    
    BucketOwnerEnforced - Access control lists (ACLs) are disabled and no longer affect permissions. The bucket owner automatically owns and has full control over every object in the bucket. The bucket only accepts PUT requests that don't specify an ACL or specify bucket owner full control ACLs (such as the predefined bucket-owner-full-control canned ACL or a custom ACL in XML format that grants the same permissions).
    
    By default, ObjectOwnership is set to BucketOwnerEnforced and ACLs are disabled. We recommend keeping ACLs disabled, except in uncommon use cases where you must control access for each object individually.
     */
    objectOwnership?: 'BucketOwnerPreferred' | 'ObjectWriter' | 'BucketOwnerEnforced';
    body?: {
        /**
         * Specifies the Region where the bucket will be created. You might choose a Region to optimize latency, minimize costs, or address regulatory requirements. For example, if you reside in Europe, you will probably find it advantageous to create buckets in the Europe (Ireland) Region.
    
        If you don't specify a Region, the bucket is created in the US East (N. Virginia) Region (us-east-1) by default. This functionality is not supported for directory buckets.
         */
        LocationConstraint?: 'af-south-1' | 'ap-east-1' | 'ap-northeast-1' | 'ap-northeast-2' | 'ap-northeast-3' | 'ap-south-1' | 'ap-south-2' | 'ap-southeast-1' | 'ap-southeast-2' | 'ap-southeast-3' | 'ca-central-1' | 'cn-north-1' | 'cn-northwest-1' | 'EU' | 'eu-central-1' | 'eu-north-1' | 'eu-south-1' | 'eu-south-2' | 'eu-west-1' | 'eu-west-2' | 'eu-west-3' | 'me-south-1' | 'sa-east-1' | 'us-east-2' | 'us-gov-east-1' | 'us-gov-west-1' | 'us-west-1' | 'us-west-2';
        /**
         * Specifies the location where the bucket will be created. This functionality is only supported by directory buckets.
    
        Directory buckets - The location type is Availability Zone or Local Zone. To use the Local Zone location type, your account must be enabled for Dedicated Local Zones. Otherwise, you get an HTTP 403 Forbidden error with the error code AccessDenied. To learn more, see Enable accounts for Dedicated Local Zones in the Amazon S3 User Guide.
         */
        Location?: {
            /**
             * The type of location where the bucket will be created.
             */
            Type?: 'AvailabilityZone' | 'LocalZone';
            /**
             * The name of the location where the bucket will be created.
      
            For directory buckets, the name of the location is the Zone ID of the Availability Zone (AZ) or Local Zone (LZ) where the bucket will be created. An example AZ ID value is usw2-az1.
             */
            Name?: string;
        };
        /**
         * Specifies the information about the bucket that will be created. This functionality is only supported by directory buckets.
         */
        Bucket?: {
            /**
             * The number of Zone (Availability Zone or Local Zone) that's used for redundancy for the bucket.
             */
            DataRedundancy?: 'SingleAvailabilityZone' | 'SingleLocalZone';
            /**
             * The type of bucket.
             */
            Type?: 'Directory';
        };
    };
}
export declare type CreatS3BucketResponseOK = undefined;
export declare type CreatS3BucketResponseError = undefined;
export interface DeleteS3BucketRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Specifies the bucket being deleted.
     */
    bucket: string;
    region: string;
    /**
     * The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
     */
    expectedBucketOwner?: string;
}
export declare type DeleteS3BucketResponseOK = undefined;
export declare type DeleteS3BucketResponseError = undefined;
export interface GetS3BucketHeadRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The bucket name.
     */
    bucket: string;
    region: string;
    /**
     * The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
     */
    expectedBucketOwner?: string;
}
export declare type GetS3BucketHeadResponseOK = undefined;
export declare type GetS3BucketHeadResponseError = undefined;
export interface GetS3BucketsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Limits the response to buckets that are located in the specified AWS Region. The AWS Region must be expressed according to the AWS Region code, such as us-west-2 for the US West (Oregon) Region.
     */
    bucketRegion: string;
    /**
     * ContinuationToken indicates to Amazon S3 that the list is being continued on this bucket with a token. ContinuationToken is obfuscated and is not a real key. You can use this ContinuationToken for pagination of the list results.
     */
    continuationToken?: string;
    /**
     * Maximum number of buckets to be returned in response. When the number is more than the count of buckets that are owned by an AWS account, return all the buckets in response.

    Valid Range: Minimum value of 1. Maximum value of 10000.
     */
    maxBuckets?: number;
    /**
     * Limits the response to bucket names that begin with the specified bucket name prefix.
     */
    prefix?: string;
}
export declare type GetS3BucketsResponseOK = S3Buckets;
export declare type GetS3BucketsResponseError = undefined;
//# sourceMappingURL=bucket.d.ts.map