/*!
 * Copyright Adaptavist 2025 (c) All rights reserved
 */
import { S3CopyObject } from '../../definitions/S3CopyObject';
import { S3HeadObject } from '../../definitions/S3HeadObject';
import { S3ObjectVersions } from '../../definitions/S3ObjectVersions';
import { S3Objects } from '../../definitions/S3Objects';
import { ErrorStrategyOption } from '../../errorStrategy';
import { HeadersOption } from '@managed-api/commons-core';
export interface CopyS3ObjectRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the destination bucket.
     */
    bucket: string;
    /**
     * The key of the destination object.
     */
    key: string;
    region: string;
    /**
     * The canned access control list (ACL) to apply to the object.

    When you copy an object, the ACL metadata is not preserved and is set to private by default. Only the owner has full access control. To override the default ACL setting, specify a new ACL when you generate a copy request.

    If the destination bucket that you're copying objects to uses the bucket owner enforced setting for S3 Object Ownership, ACLs are disabled and no longer affect permissions. Buckets that use this setting only accept PUT requests that don't specify an ACL or PUT requests that specify bucket owner full control ACLs, such as the bucket-owner-full-control canned ACL or an equivalent form of this ACL expressed in the XML format.
     */
    acl?: 'private' | 'public-read' | 'public-read-write' | 'authenticated-read' | 'aws-exec-read' | 'bucket-owner-read' | 'bucket-owner-full-control';
    /**
     * Specifies the caching behavior along the request/reply chain.
     */
    cacheControl?: string;
    /**
     * Indicates the algorithm that you want Amazon S3 to use to create the checksum for the object.

    When you copy an object, if the source object has a checksum, that checksum value will be copied to the new object by default. If the CopyObject request does not include this x-amz-checksum-algorithm header, the checksum algorithm will be copied from the source object to the destination object (if it's present on the source object). You can optionally specify a different checksum algorithm to use with the x-amz-checksum-algorithm header. Unrecognized or unsupported values will respond with the HTTP status code 400 Bad Request.
     */
    checksumAlgorithm?: 'CRC32' | 'CRC32C' | 'SHA1' | 'SHA256' | 'CRC64NVME';
    /**
     * Specifies presentational information for the object. Indicates whether an object should be displayed in a web browser or downloaded as a file. It allows specifying the desired filename for the downloaded file.
     */
    contentDisposition?: string;
    /**
     * Specifies what content encodings have been applied to the object and thus what decoding mechanisms must be applied to obtain the media-type referenced by the Content-Type header field.
     */
    contentEncoding?: string;
    /**
     * The language the content is in.
     */
    contentLanguage?: string;
    /**
     * A standard MIME type that describes the format of the object data.
     */
    contentType?: string;
    /**
     * Specifies the source object for the copy operation. The source object can be up to 5 GB. If the source object is an object that was uploaded by using a multipart upload, the object copy will be a single part object after the source object is copied to the destination bucket.

    You specify the value of the copy source in one of two formats, depending on whether you want to access the source object through an access point:

    ** For objects not accessed through an access point, specify the name of the source bucket and the key of the source object, separated by a slash (/). For example, to copy the object reports/january.pdf from the general purpose bucket awsexamplebucket, use awsexamplebucket/reports/january.pdf. The value must be URL-encoded. To copy the object reports/january.pdf from the directory bucket awsexamplebucket--use1-az5--x-s3, use awsexamplebucket--use1-az5--x-s3/reports/january.pdf. The value must be URL-encoded.

    ** For objects accessed through access points, specify the Amazon Resource Name (ARN) of the object as accessed through the access point, in the format arn:aws:s3:<Region>:<account-id>:accesspoint/<access-point-name>/object/<key>. For example, to copy the object reports/january.pdf through access point my-access-point owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3:us-west-2:123456789012:accesspoint/my-access-point/object/reports/january.pdf. The value must be URL encoded.

    Alternatively, for objects accessed through Amazon S3 on Outposts, specify the ARN of the object as accessed in the format arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/object/<key>. For example, to copy the object reports/january.pdf through outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/object/reports/january.pdf. The value must be URL-encoded.

    If your source bucket versioning is enabled, the x-amz-copy-source header by default identifies the current version of an object to copy. If the current version is a delete marker, Amazon S3 behaves as if the object was deleted. To copy a different version, use the versionId query parameter. Specifically, append ?versionId=<version-id> to the value (for example, awsexamplebucket/reports/january.pdf?versionId=QUpfdndhfd8438MNFDN93jdnJFkdmqnh893). If you don't specify a version ID, Amazon S3 copies the latest version of the source object.

    If you enable versioning on the destination bucket, Amazon S3 generates a unique version ID for the copied object. This version ID is different from the version ID of the source object. Amazon S3 returns the version ID of the copied object in the x-amz-version-id response header in the response.

    If you do not enable versioning or suspend it on the destination bucket, the version ID that Amazon S3 generates in the x-amz-version-id response header is always null.

    Pattern: \/?.+\/.+
     */
    copySource: string;
    /**
     * Copies the object if its entity tag (ETag) matches the specified tag.

    If both the x-amz-copy-source-if-match and x-amz-copy-source-if-unmodified-since headers are present in the request and evaluate as follows, Amazon S3 returns 200 OK and copies the data:

    ** x-amz-copy-source-if-match condition evaluates to true

    ** x-amz-copy-source-if-unmodified-since condition evaluates to false
     */
    copySourceIfMatch?: string;
    /**
     * Copies the object if it has been modified since the specified time.

    If both the x-amz-copy-source-if-none-match and x-amz-copy-source-if-modified-since headers are present in the request and evaluate as follows, Amazon S3 returns the 412 Precondition Failed response code:

    ** x-amz-copy-source-if-none-match condition evaluates to false

    ** x-amz-copy-source-if-modified-since condition evaluates to true
     */
    copySourceIfModifiedSince?: string;
    /**
     * Copies the object if its entity tag (ETag) is different than the specified ETag.

    If both the x-amz-copy-source-if-none-match and x-amz-copy-source-if-modified-since headers are present in the request and evaluate as follows, Amazon S3 returns the 412 Precondition Failed response code:

    ** x-amz-copy-source-if-none-match condition evaluates to false

    ** x-amz-copy-source-if-modified-since condition evaluates to true
     */
    copySourceIfNoneMatch?: string;
    /**
     * Copies the object if it hasn't been modified since the specified time.

    If both the x-amz-copy-source-if-match and x-amz-copy-source-if-unmodified-since headers are present in the request and evaluate as follows, Amazon S3 returns 200 OK and copies the data:

    ** x-amz-copy-source-if-match condition evaluates to true

    ** x-amz-copy-source-if-unmodified-since condition evaluates to false
     */
    copySourceIfUnmodifiedSince?: string;
    /**
     * The date and time at which the object is no longer cacheable.
     */
    expires?: string;
    /**
     * Gives the grantee READ, READ_ACP, and WRITE_ACP permissions on the object.
     */
    grantFullControl?: string;
    /**
     * Allows grantee to read the object data and its metadata.
     */
    grantRead?: string;
    /**
     * Allows grantee to read the object ACL.
     */
    grantReadACP?: string;
    /**
     * Allows grantee to write the ACL for the applicable object.
     */
    grantWriteACP?: string;
    /**
     * Specifies whether the metadata is copied from the source object or replaced with metadata that's provided in the request. When copying an object, you can preserve all metadata (the default) or specify new metadata. If this header isn’t specified, COPY is the default behavior.

    General purpose bucket - For general purpose buckets, when you grant permissions, you can use the s3:x-amz-metadata-directive condition key to enforce certain metadata behavior when objects are uploaded.
     */
    metadataDirective?: 'COPY' | 'REPLACE';
    /**
     * Specifies whether the object tag-set is copied from the source object or replaced with the tag-set that's provided in the request.

    The default value is COPY.
     */
    taggingDirective?: 'COPY' | 'REPLACE';
    /**
     * The server-side encryption algorithm used when storing this object in Amazon S3. Unrecognized or unsupported values won’t write a destination object and will receive a 400 Bad Request response.

    Amazon S3 automatically encrypts all new objects that are copied to an S3 bucket. When copying an object, if you don't specify encryption information in your copy request, the encryption setting of the target object is set to the default encryption configuration of the destination bucket. By default, all buckets have a base level of encryption configuration that uses server-side encryption with Amazon S3 managed keys (SSE-S3). If the destination bucket has a different default encryption configuration, Amazon S3 uses the corresponding encryption key to encrypt the target object copy.

    With server-side encryption, Amazon S3 encrypts your data as it writes your data to disks in its data centers and decrypts the data when you access it.

    General purpose buckets

    ** For general purpose buckets, there are the following supported options for server-side encryption: server-side encryption with AWS Key Management Service (AWS KMS) keys (SSE-KMS), dual-layer server-side encryption with AWS KMS keys (DSSE-KMS), and server-side encryption with customer-provided encryption keys (SSE-C). Amazon S3 uses the corresponding KMS key, or a customer-provided key to encrypt the target object copy.

    ** When you perform a CopyObject operation, if you want to use a different type of encryption setting for the target object, you can specify appropriate encryption-related headers to encrypt the target object with an Amazon S3 managed key, a KMS key, or a customer-provided key. If the encryption setting in your request is different from the default encryption configuration of the destination bucket, the encryption setting in your request takes precedence.

    Directory buckets

    ** For directory buckets, there are only two supported options for server-side encryption: server-side encryption with Amazon S3 managed keys (SSE-S3) (AES256) and server-side encryption with AWS KMS keys (SSE-KMS) (aws:kms). We recommend that the bucket's default encryption uses the desired encryption configuration and you don't override the bucket default encryption in your CreateSession requests or PUT object requests. Then, new objects are automatically encrypted with the desired encryption settings.

    ** To encrypt new object copies to a directory bucket with SSE-KMS, we recommend you specify SSE-KMS as the directory bucket's default encryption configuration with a KMS key (specifically, a customer managed key). The AWS managed key (aws/s3) isn't supported. Your SSE-KMS configuration can only support 1 customer managed key per directory bucket for the lifetime of the bucket. After you specify a customer managed key for SSE-KMS, you can't override the customer managed key for the bucket's SSE-KMS configuration. Then, when you perform a CopyObject operation and want to specify server-side encryption settings for new object copies with SSE-KMS in the encryption-related request headers, you must ensure the encryption key is the same customer managed key that you specified for the directory bucket's default encryption configuration.
     */
    serverSideEncryption?: 'AES256' | 'aws:kms' | 'aws:kms:dsse';
    /**
     * If the x-amz-storage-class header is not used, the copied object will be stored in the STANDARD Storage Class by default. The STANDARD storage class provides high durability and high availability. Depending on performance needs, you can specify a different Storage Class.

    You can use the CopyObject action to change the storage class of an object that is already stored in Amazon S3 by using the x-amz-storage-class header.

    Before using an object as a source object for the copy operation, you must restore a copy of it if it meets any of the following conditions:

    ** The storage class of the source object is GLACIER or DEEP_ARCHIVE.

    ** The storage class of the source object is INTELLIGENT_TIERING and it's S3 Intelligent-Tiering access tier is Archive Access or Deep Archive Access.
     */
    storageClass?: 'STANDARD' | 'REDUCED_REDUNDANCY' | 'STANDARD_IA' | 'ONEZONE_IA' | 'INTELLIGENT_TIERING' | 'GLACIER' | 'DEEP_ARCHIVE' | 'OUTPOSTS' | 'GLACIER_IR' | 'SNOW' | 'EXPRESS_ONEZONE';
    /**
     * If the destination bucket is configured as a website, redirects requests for this object copy to another object in the same bucket or to an external URL. Amazon S3 stores the value of this header in the object metadata. This value is unique to each object and is not copied when using the x-amz-metadata-directive header. Instead, you may opt to provide this header in combination with the x-amz-metadata-directive header.
     */
    websiteRedirectLocation?: string;
    /**
     * Specifies the algorithm to use when encrypting the object (for example, AES256).

    When you perform a CopyObject operation, if you want to use a different type of encryption setting for the target object, you can specify appropriate encryption-related headers to encrypt the target object with an Amazon S3 managed key, a KMS key, or a customer-provided key. If the encryption setting in your request is different from the default encryption configuration of the destination bucket, the encryption setting in your request takes precedence.
     */
    sseCustomerAlgorithm?: string;
    /**
     * Specifies the customer-provided encryption key for Amazon S3 to use in encrypting data. This value is used to store the object and then it is discarded. Amazon S3 does not store the encryption key. The key must be appropriate for use with the algorithm specified in the x-amz-server-side-encryption-customer-algorithm header.
     */
    sseCustomerKey?: string;
    /**
     * Specifies the 128-bit MD5 digest of the encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error.
     */
    sseCustomerKeyMD5?: string;
    /**
     * Specifies the AWS KMS key ID (Key ID, Key ARN, or Key Alias) to use for object encryption. All GET and PUT requests for an object protected by AWS KMS will fail if they're not made via SSL or using SigV4.

    Directory buckets - To encrypt data using SSE-KMS, it's recommended to specify the x-amz-server-side-encryption header to aws:kms. Then, the x-amz-server-side-encryption-aws-kms-key-id header implicitly uses the bucket's default KMS customer managed key ID. If you want to explicitly set the x-amz-server-side-encryption-aws-kms-key-id header, it must match the bucket's default customer managed key (using key ID or ARN, not alias). Your SSE-KMS configuration can only support 1 customer managed key per directory bucket's lifetime. The AWS managed key (aws/s3) isn't supported. Incorrect key specification results in an HTTP 400 Bad Request error.
     */
    sseKMSKeyId?: string;
    /**
     * Specifies the AWS KMS Encryption Context as an additional encryption context to use for the destination object encryption. The value of this header is a base64-encoded UTF-8 string holding JSON with the encryption context key-value pairs.

    ** General purpose buckets - This value must be explicitly added to specify encryption context for CopyObject requests if you want an additional encryption context for your destination object. The additional encryption context of the source object won't be copied to the destination object.

    ** Directory buckets - You can optionally provide an explicit encryption context value. The value must match the default encryption context - the bucket Amazon Resource Name (ARN). An additional encryption context value is not supported.
     */
    sseKMSEncryptionContext?: string;
    /**
     * Specifies whether Amazon S3 should use an S3 Bucket Key for object encryption with server-side encryption using AWS Key Management Service (AWS KMS) keys (SSE-KMS). If a target object uses SSE-KMS, you can enable an S3 Bucket Key for the object.

    etting this header to true causes Amazon S3 to use an S3 Bucket Key for object encryption with SSE-KMS. Specifying this header with a COPY action doesn’t affect bucket-level settings for S3 Bucket Key.
     */
    ssebucketKeyEnabled?: boolean;
    /**
     * Specifies the algorithm to use when decrypting the source object (for example, AES256).

    If the source object for the copy is stored in Amazon S3 using SSE-C, you must provide the necessary encryption information in your request so that Amazon S3 can decrypt the object for copying.
     */
    copySourceSSECustomerAlgorithm?: string;
    /**
     * Specifies the customer-provided encryption key for Amazon S3 to use to decrypt the source object. The encryption key provided in this header must be the same one that was used when the source object was created.

    If the source object for the copy is stored in Amazon S3 using SSE-C, you must provide the necessary encryption information in your request so that Amazon S3 can decrypt the object for copying.
     */
    copySourceSSECustomerKey?: string;
    /**
     * Specifies the 128-bit MD5 digest of the encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error.

    If the source object for the copy is stored in Amazon S3 using SSE-C, you must provide the necessary encryption information in your request so that Amazon S3 can decrypt the object for copying.
     */
    copySourceSSECustomerKeyMD5?: string;
    /**
     * Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for corresponding charges to copy the object.
     */
    requestPayer?: 'requester';
    /**
     * The tag-set for the object copy in the destination bucket. This value must be used in conjunction with the x-amz-tagging-directive if you choose REPLACE for the x-amz-tagging-directive. If you choose COPY for the x-amz-tagging-directive, you don't need to set the x-amz-tagging header, because the tag-set will be copied from the source object directly. The tag-set must be encoded as URL Query parameters.

    The default value is the empty value.
     */
    tagging?: string;
    /**
     * The Object Lock mode that you want to apply to the object copy.
     */
    objectLockMode?: 'GOVERNANCE' | 'COMPLIANCE';
    /**
     * The date and time when you want the Object Lock of the object copy to expire.
     */
    objectLockRetainUntilDate?: string;
    /**
     * Specifies whether you want to apply a legal hold to the object copy.
     */
    objectLockLegalHoldStatus?: 'ON' | 'OFF';
    /**
     * The account ID of the expected source bucket owner. If the account ID that you provide does not match the actual owner of the source bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
     */
    expectedBucketOwner?: string;
    /**
     * The account ID of the expected destination bucket owner. If the account ID that you provide does not match the actual owner of the destination bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
     */
    expectedSourceBucketOwner?: string;
}
export declare type CopyS3ObjectResponseOK = S3CopyObject;
export declare type CopyS3ObjectResponseError = undefined;
export interface DeleteS3ObjectRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The bucket name of the bucket containing the object.
     */
    bucket: string;
    /**
     * Key name of the object to delete.
     */
    key: string;
    region: string;
    /**
     * Version ID used to reference a specific version of the object.
     */
    versionId?: string;
    /**
     * The If-Match header field makes the request method conditional on ETags. If the ETag value does not match, the operation returns a 412 Precondition Failed error. If the ETag matches or if the object doesn't exist, the operation will return a 204 Success (No Content) response. This functionality is only supported for directory buckets.
     */
    ifMatch?: string;
    /**
     * The concatenation of the authentication device's serial number, a space, and the value that is displayed on your authentication device. Required to permanently delete a versioned object if versioning is configured with MFA delete enabled. This functionality is not supported for directory buckets.
     */
    mfa?: string;
    /**
     * Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for corresponding charges to copy the object. This functionality is not supported for directory buckets.
     */
    requestPayer?: 'requester';
    /**
     * Indicates whether S3 Object Lock should bypass Governance-mode restrictions to process this operation. To use this header, you must have the s3:BypassGovernanceRetention permission. This functionality is not supported for directory buckets.
     */
    bypassGovernanceRetention?: boolean;
    /**
     * The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied)
     */
    expectedBucketOwner?: string;
    /**
     * If present, the object is deleted only if its modification times matches the provided Timestamp. If the Timestamp values do not match, the operation returns a 412 Precondition Failed error. If the Timestamp matches or if the object doesn’t exist, the operation returns a 204 Success (No Content) response. This functionality is only supported for directory buckets.
     */
    ifMatchLastModifiedTime?: string;
    /**
     * If present, the object is deleted only if its size matches the provided size in bytes. If the Size value does not match, the operation returns a 412 Precondition Failed error. If the Size matches or if the object doesn’t exist, the operation returns a 204 Success (No Content) response. This functionality is only supported for directory buckets.
     */
    ifMatchSize?: number;
}
export declare type DeleteS3ObjectResponseOK = undefined;
export declare type DeleteS3ObjectResponseError = undefined;
export interface GetS3ObjectRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The bucket name containing the object.
     */
    bucket: string;
    /**
     * Key of the object to get.
     */
    key: string;
    region: string;
    /**
     * Part number of the object being read. This is a positive integer between 1 and 10,000. Effectively performs a 'ranged' GET request for the part specified. Useful for downloading just a part of an object.
     */
    partNumber?: number;
    /**
     * Sets the Cache-Control header of the response.
     */
    responseCacheControl?: string;
    /**
     * Sets the Content-Disposition header of the response.
     */
    responseContentDisposition?: string;
    /**
     * Sets the Content-Encoding header of the response.
     */
    responseContentEncoding?: string;
    /**
     * Sets the Content-Language header of the response.
     */
    responseContentLanguage?: string;
    /**
     * Sets the Content-Type header of the response.
     */
    responseContentType?: string;
    /**
     * Sets the Expires header of the response.
     */
    responseExpires?: string;
    /**
     * Version ID used to reference a specific version of the object.

    By default, the GetObject operation returns the current version of an object. To return a different version, use the versionId subresource.
     */
    versionId?: string;
    /**
     * Return the object only if its entity tag (ETag) is the same as the one specified in this header; otherwise, return a 412 Precondition Failed error.

    If both of the If-Match and If-Unmodified-Since headers are present in the request as follows: If-Match condition evaluates to true, and; If-Unmodified-Since condition evaluates to false; then, S3 returns 200 OK and the data requested.
     */
    ifMatch?: string;
    /**
     * Return the object only if it has been modified since the specified time; otherwise, return a 304 Not Modified error.

    If both of the If-None-Match and If-Modified-Since headers are present in the request as follows: If-None-Match condition evaluates to false, and; If-Modified-Since condition evaluates to true; then, S3 returns 304 Not Modified status code.
     */
    ifModifiedSince?: string;
    /**
     * Return the object only if its entity tag (ETag) is different from the one specified in this header; otherwise, return a 304 Not Modified error.

    If both of the If-None-Match and If-Modified-Since headers are present in the request as follows: If-None-Match condition evaluates to false, and; If-Modified-Since condition evaluates to true; then, S3 returns 304 Not Modified HTTP status code.
     */
    ifNoneMatch?: string;
    /**
     * Return the object only if it has not been modified since the specified time; otherwise, return a 412 Precondition Failed error.

    If both of the If-Match and If-Unmodified-Since headers are present in the request as follows: If-Match condition evaluates to true, and; If-Unmodified-Since condition evaluates to false; then, S3 returns 200 OK and the data requested.
     */
    ifUnmodifiedSince?: string;
    /**
     * Downloads the specified byte range of an object
     */
    range?: string;
    /**
     * Specifies the algorithm to use when decrypting the object (for example, AES256). This functionality is not supported for directory buckets.

    If you encrypt an object by using server-side encryption with customer-provided encryption keys (SSE-C) when you store the object in Amazon S3, then when you GET the object, you must use the following headers:

    ** x-amz-server-side-encryption-customer-algorithm

    ** x-amz-server-side-encryption-customer-key

    ** x-amz-server-side-encryption-customer-key-MD5
     */
    ssCustomerAlgorithm?: string;
    /**
     * Specifies the customer-provided encryption key that you originally provided for Amazon S3 to encrypt the data before storing it. This value is used to decrypt the object when recovering it and must match the one used when storing the data. The key must be appropriate for use with the algorithm specified in the x-amz-server-side-encryption-customer-algorithm header. This functionality is not supported for directory buckets.

    If you encrypt an object by using server-side encryption with customer-provided encryption keys (SSE-C) when you store the object in Amazon S3, then when you GET the object, you must use the following headers:

    ** x-amz-server-side-encryption-customer-algorithm

    ** x-amz-server-side-encryption-customer-key

    ** x-amz-server-side-encryption-customer-key-MD5
     */
    sseCustomerKey?: string;
    /**
     * Specifies the 128-bit MD5 digest of the customer-provided encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error. This functionality is not supported for directory buckets.

    If you encrypt an object by using server-side encryption with customer-provided encryption keys (SSE-C) when you store the object in Amazon S3, then when you GET the object, you must use the following headers:

    ** x-amz-server-side-encryption-customer-algorithm

    ** x-amz-server-side-encryption-customer-key

    ** x-amz-server-side-encryption-customer-key-MD5
     */
    sseCustomerKeyMD5?: string;
    /**
     * Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for corresponding charges to copy the object. This functionality is not supported for directory buckets.
     */
    requestPayer?: 'requester';
    /**
     * The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
     */
    expectedBucketOwner?: string;
    /**
     * To retrieve the checksum, this mode must be enabled.
     */
    checksumMode?: 'ENABLED';
}
export declare type GetS3ObjectResponseOK = ArrayBuffer;
export declare type GetS3ObjectResponseError = undefined;
export interface GetS3ObjectHeadRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the bucket that contains the object.
     */
    bucket: string;
    /**
     * The object key.
     */
    key: string;
    region: string;
    /**
     * Part number of the object being read. This is a positive integer between 1 and 10,000. Effectively performs a 'ranged' HEAD request for the part specified. Useful querying about the size of the part and the number of parts in this object.
     */
    partNumber?: number;
    /**
     * Sets the Cache-Control header of the response.
     */
    responseCacheControl?: string;
    /**
     * Sets the Content-Disposition header of the response.
     */
    responseContentDisposition?: string;
    /**
     * Sets the Content-Encoding header of the response.
     */
    responseContentEncoding?: string;
    /**
     * Sets the Content-Language header of the response.
     */
    responseContentLanguage?: string;
    /**
     * Sets the Content-Type header of the response.
     */
    responseContentType?: string;
    /**
     * Sets the Expires header of the response.
     */
    responseExpires?: string;
    /**
     * Version ID used to reference a specific version of the object.
     */
    versionId?: string;
    /**
     * Return the object only if its entity tag (ETag) is the same as the one specified; otherwise, return a 412 (precondition failed) error.

    If both of the If-Match and If-Unmodified-Since headers are present in the request as follows:

    ** If-Match condition evaluates to true, and;

    ** If-Unmodified-Since condition evaluates to false;

    Then Amazon S3 returns 200 OK and the data requested.
     */
    ifMatch?: string;
    /**
     * Return the object only if it has been modified since the specified time; otherwise, return a 304 (not modified) error.

    If both of the If-None-Match and If-Modified-Since headers are present in the request as follows:

    ** If-None-Match condition evaluates to false, and;

    ** If-Modified-Since condition evaluates to true;

    Then Amazon S3 returns the 304 Not Modified response code.
      */
    ifModifiedSince?: string;
    /**
     * Return the object only if its entity tag (ETag) is different from the one specified; otherwise, return a 304 (not modified) error.

    If both of the If-None-Match and If-Modified-Since headers are present in the request as follows:

    ** If-None-Match condition evaluates to false, and;

    ** If-Modified-Since condition evaluates to true;

    Then Amazon S3 returns the 304 Not Modified response code.
     */
    ifNoneMatch?: string;
    /**
     * Return the object only if it has not been modified since the specified time; otherwise, return a 412 (precondition failed) error.

    If both of the If-Match and If-Unmodified-Since headers are present in the request as follows:

    ** If-Match condition evaluates to true, and;

    ** If-Unmodified-Since condition evaluates to false;

    Then Amazon S3 returns 200 OK and the data requested.
     */
    ifUnmodifiedSince?: string;
    /**
     * HeadObject returns only the metadata for an object. If the Range is satisfiable, only the ContentLength is affected in the response. If the Range is not satisfiable, S3 returns a 416 - Requested Range Not Satisfiable error.
     */
    range?: string;
    /**
     * Specifies the algorithm to use when encrypting the object (for example, AES256). This functionality is not supported for directory buckets.
     */
    sseCustomerAlgorithm?: string;
    /**
     * Specifies the customer-provided encryption key for Amazon S3 to use in encrypting data. This value is used to store the object and then it is discarded; Amazon S3 does not store the encryption key. The key must be appropriate for use with the algorithm specified in the x-amz-server-side-encryption-customer-algorithm header. This functionality is not supported for directory buckets.
     */
    sseCustomerKey?: string;
    /**
     * Specifies the 128-bit MD5 digest of the encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error. This functionality is not supported for directory buckets.
     */
    sseCustomerKeyMD5?: string;
    /**
     * Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for corresponding charges to copy the object. This functionality is not supported for directory buckets.
     */
    requestPayer?: 'requester';
    /**
     * The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
     */
    expectedBucketOwner?: string;
    /**
     * To retrieve the checksum, this parameter must be enabled.

    General purpose buckets - If you enable checksum mode and the object is uploaded with a checksum and encrypted with an AWS Key Management Service (AWS KMS) key, you must have permission to use the kms:Decrypt action to retrieve the checksum.

    Directory buckets - If you enable ChecksumMode and the object is encrypted with AWS Key Management Service (AWS KMS), you must also have the kms:GenerateDataKey and kms:Decrypt permissions in IAM identity-based policies and AWS KMS key policies for the AWS KMS key to retrieve the checksum of the object.
     */
    checksumMode?: 'ENABLED';
}
export declare type GetS3ObjectHeadResponseOK = S3HeadObject;
export declare type GetS3ObjectHeadResponseError = undefined;
export interface GetS3ObjectsV2Request extends HeadersOption, ErrorStrategyOption {
    /**
     * The bucket name that contains the objects.
     */
    bucket: string;
    region: string;
    /**
     * ContinuationToken indicates to Amazon S3 that the list is being continued on this bucket with a token. ContinuationToken is obfuscated and is not a real key. You can use this ContinuationToken for pagination of the list results.
     */
    continuationToken?: string;
    /**
     * A delimiter is a character that you use to group keys.
     */
    delimiter?: string;
    /**
     * Encoding type used by Amazon S3 to encode the object keys in the response. Responses are encoded only in UTF-8. An object key can contain any Unicode character. However, the XML 1.0 parser can't parse certain characters, such as characters with an ASCII value from 0 to 10. For characters that aren't supported in XML 1.0, you can add this parameter to request that Amazon S3 encode the keys in the response.
     */
    encodingType?: 'url';
    /**
     * The owner field is not present in ListObjectsV2 by default. If you want to return the owner field with each key in the result, then set the FetchOwner field to true.
     */
    fetchOwner?: boolean;
    /**
     * Sets the maximum number of keys returned in the response. By default, the action returns up to 1,000 key names. The response might contain fewer keys but will never contain more.
     */
    maxKeys?: number;
    /**
     * Limits the response to keys that begin with the specified prefix.
     */
    prefix?: string;
    /**
     * StartAfter is where you want Amazon S3 to start listing from. Amazon S3 starts listing after this specified key. StartAfter can be any key in the bucket.
     */
    startAfter?: string;
    /**
     * Confirms that the requester knows that she or he will be charged for the list objects request in V2 style. Bucket owners need not specify this parameter in their requests.
     */
    requestPayer?: 'requester';
    /**
     * The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
     */
    expectedBucketOwner?: string;
    /**
     * Specifies the optional fields that you want returned in the response. Fields that you do not specify are not returned.
     */
    optionalObjectAttributes?: 'RestoreStatus';
}
export declare type GetS3ObjectsV2ResponseOK = S3Objects;
export declare type GetS3ObjectsV2ResponseError = undefined;
export interface GetS3ObjectVersionsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The bucket name that contains the objects.
     */
    bucket: string;
    region: string;
    /**
     * A delimiter is a character that you specify to group keys. All keys that contain the same string between the prefix and the first occurrence of the delimiter are grouped under a single result element in CommonPrefixes. These groups are counted as one result against the max-keys limitation. These keys are not returned elsewhere in the response.
     */
    delimiter?: string;
    /**
     * Encoding type used by Amazon S3 to encode the object keys in the response. Responses are encoded only in UTF-8. An object key can contain any Unicode character. However, the XML 1.0 parser can't parse certain characters, such as characters with an ASCII value from 0 to 10. For characters that aren't supported in XML 1.0, you can add this parameter to request that Amazon S3 encode the keys in the response
     */
    encodingType?: 'url';
    /**
     * Specifies the key to start with when listing objects in a bucket.
     */
    keyMarker?: string;
    /**
     * Sets the maximum number of keys returned in the response. By default, the action returns up to 1,000 key names. The response might contain fewer keys but will never contain more. If additional keys satisfy the search criteria, but were not returned because max-keys was exceeded, the response contains <isTruncated>true</isTruncated>. To return the additional keys, see key-marker and version-id-marker.
     */
    maxKeys?: number;
    /**
     * Use this parameter to select only those keys that begin with the specified prefix. You can use prefixes to separate a bucket into different groupings of keys. (You can think of using prefix to make groups in the same way that you'd use a folder in a file system.) You can use prefix with delimiter to roll up numerous objects into a single result under CommonPrefixes.
     */
    prefix?: string;
    /**
     * Specifies the object version you want to start listing from.
     */
    versionIdMarker?: string;
    /**
     * The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
     */
    expectedBucketOwner?: string;
    /**
     * Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for corresponding charges to copy the object.
     */
    requestPayer?: 'requester';
    /**
     * Specifies the optional fields that you want returned in the response. Fields that you do not specify are not returned.
     */
    optionalObjectAttributes?: 'RestoreStatus';
}
export declare type GetS3ObjectVersionsResponseOK = S3ObjectVersions;
export declare type GetS3ObjectVersionsResponseError = undefined;
export interface PutS3ObjectRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The bucket name to which the PUT action was initiated.
     */
    bucket: string;
    /**
     * Object key for which the PUT action was initiated.
     */
    key: string;
    region: string;
    body: ArrayBuffer | string;
    /**
     * The canned ACL to apply to the object.

    When adding a new object, you can use headers to grant ACL-based permissions to individual AWS accounts or to predefined groups defined by Amazon S3. These permissions are then added to the ACL on the object. By default, all objects are private. Only the owner has full access control.

    If the bucket that you're uploading objects to uses the bucket owner enforced setting for S3 Object Ownership, ACLs are disabled and no longer affect permissions. Buckets that use this setting only accept PUT requests that don't specify an ACL or PUT requests that specify bucket owner full control ACLs, such as the bucket-owner-full-control canned ACL or an equivalent form of this ACL expressed in the XML format. PUT requests that contain other ACLs (for example, custom grants to certain AWS accounts) fail and return a 400 error with the error code AccessControlListNotSupported.
     */
    acl?: 'private' | 'public-read' | 'public-read-write' | 'authenticated-read' | 'aws-exec-read' | 'bucket-owner-read' | 'bucket-owner-full-control';
    /**
     * Can be used to specify caching behavior along the request/reply chain.
     */
    cacheControl?: string;
    /**
     * Specifies presentational information for the object.
     */
    contentDisposition?: string;
    /**
     * Specifies what content encodings have been applied to the object and thus what decoding mechanisms must be applied to obtain the media-type referenced by the Content-Type header field.
     */
    contentEncoding?: string;
    /**
     * The language the content is in.
     */
    contentLanguage?: string;
    /**
     * Size of the body in bytes. This parameter is useful when the size of the body cannot be determined automatically.
     */
    contentLength?: number;
    /**
     * The Base64 encoded 128-bit MD5 digest of the message (without the headers) according to RFC 1864. This header can be used as a message integrity check to verify that the data is the same data that was originally sent. Although it is optional, we recommend using the Content-MD5 mechanism as an end-to-end integrity check.
     */
    contentMD5?: string;
    /**
     * A standard MIME type describing the format of the contents.
     */
    contentType?: string;
    /**
     * Indicates the algorithm used to create the checksum for the object when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding x-amz-checksum-algorithm or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code 400 Bad Request.

    If the individual checksum value you provide through x-amz-checksum-algorithm doesn't match the checksum algorithm you set through x-amz-sdk-checksum-algorithm, Amazon S3 fails the request with a BadDigest error.

    For directory buckets, when you use AWS SDKs, CRC32 is the default checksum algorithm that's used for performance.
     */
    checksumAlgorithm?: 'CRC32' | 'CRC32C' | 'SHA1' | 'SHA256' | 'CRC64NVME';
    /**
     * This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit CRC-32 checksum of the object.
     */
    checksumCRC32?: string;
    /**
     * This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit CRC-32C checksum of the object.
     */
    checksumCRC32C?: string;
    /**
     * This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 64-bit CRC-64NVME checksum of the object. The CRC-64NVME checksum is always a full object checksum.
     */
    checksumCRC64NVME?: string;
    /**
     * This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 160-bit SHA-1 digest of the object.
     */
    checksumSHA1?: string;
    /**
     * This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 256-bit SHA-256 digest of the object.
     */
    checksumSHA256?: string;
    /**
     * The date and time at which the object is no longer cacheable.
     */
    expires?: string;
    /**
     * Uploads the object only if the ETag (entity tag) value provided during the WRITE operation matches the ETag of the object in S3. If the ETag values do not match, the operation returns a 412 Precondition Failed error.

    If a conflicting operation occurs during the upload S3 returns a 409 ConditionalRequestConflict response. On a 409 failure you should fetch the object's ETag and retry the upload.

    Expects the ETag value as a string.
     */
    ifMatch?: string;
    /**
     * Uploads the object only if the object key name does not already exist in the bucket specified. Otherwise, Amazon S3 returns a 412 Precondition Failed error.

    If a conflicting operation occurs during the upload S3 returns a 409 ConditionalRequestConflict response. On a 409 failure you should retry the upload.

    Expects the '*' (asterisk) character.
     */
    ifNoneMatch?: string;
    /**
     * Gives the grantee READ, READ_ACP, and WRITE_ACP permissions on the object.
     */
    grantFullControl?: string;
    /**
     * Allows grantee to read the object data and its metadata.
     */
    grantRead?: string;
    /**
     * Allows grantee to read the object ACL.
     */
    grantReadACP?: string;
    /**
     * Allows grantee to write the ACL for the applicable object.
     */
    grantWriteACP?: string;
    /**
     * Specifies the offset for appending data to existing objects in bytes. The offset must be equal to the size of the existing object being appended to. If no object exists, setting this header to 0 will create a new object.
     */
    writeOffsetBytes?: number;
    /**
     * The server-side encryption algorithm that was used when you store this object in Amazon S3 (for example, AES256, aws:kms, aws:kms:dsse).

    ** General purpose buckets - You have four mutually exclusive options to protect data using server-side encryption in Amazon S3, depending on how you choose to manage the encryption keys. Specifically, the encryption key options are Amazon S3 managed keys (SSE-S3), AWS KMS keys (SSE-KMS or DSSE-KMS), and customer-provided keys (SSE-C). Amazon S3 encrypts data with server-side encryption by using Amazon S3 managed keys (SSE-S3) by default. You can optionally tell Amazon S3 to encrypt data at rest by using server-side encryption with other key options.

    ** Directory buckets - For directory buckets, there are only two supported options for server-side encryption: server-side encryption with Amazon S3 managed keys (SSE-S3) (AES256) and server-side encryption with AWS KMS keys (SSE-KMS) (aws:kms). We recommend that the bucket's default encryption uses the desired encryption configuration and you don't override the bucket default encryption in your CreateSession requests or PUT object requests. Then, new objects are automatically encrypted with the desired encryption settings.
    In the Zonal endpoint API calls (except CopyObject and UploadPartCopy) using the REST API, the encryption request headers must match the encryption settings that are specified in the CreateSession request. You can't override the values of the encryption settings (x-amz-server-side-encryption, x-amz-server-side-encryption-aws-kms-key-id, x-amz-server-side-encryption-context, and x-amz-server-side-encryption-bucket-key-enabled) that are specified in the CreateSession request. You don't need to explicitly specify these encryption settings values in Zonal endpoint API calls, and Amazon S3 will use the encryption settings values from the CreateSession request to protect new objects in the directory bucket.
     */
    serverSideEncryption?: 'AES256' | 'aws:kms' | 'aws:kms:dsse';
    /**
     * By default, Amazon S3 uses the STANDARD Storage Class to store newly created objects. The STANDARD storage class provides high durability and high availability. Depending on performance needs, you can specify a different Storage Class.
     */
    storageClass?: 'STANDARD' | 'REDUCED_REDUNDANCY' | 'STANDARD_IA' | 'ONEZONE_IA' | 'INTELLIGENT_TIERING' | 'GLACIER' | 'DEEP_ARCHIVE' | 'OUTPOSTS' | 'GLACIER_IR' | 'SNOW' | 'EXPRESS_ONEZONE';
    /**
     * If the bucket is configured as a website, redirects requests for this object to another object in the same bucket or to an external URL. Amazon S3 stores the value of this header in the object metadata.

    In the following example, the request header sets the redirect to an object (anotherPage.html) in the same bucket:

    x-amz-website-redirect-location: /anotherPage.html

    In the following example, the request header sets the object redirect to another website:

    x-amz-website-redirect-location: http://www.example.com/
     */
    websiteRedirectLocation?: string;
    /**
     * Specifies the algorithm to use when encrypting the object (for example, AES256).
     */
    sseCustomerAlgorithm?: string;
    /**
     * Specifies the customer-provided encryption key for Amazon S3 to use in encrypting data. This value is used to store the object and then it is discarded; Amazon S3 does not store the encryption key. The key must be appropriate for use with the algorithm specified in the x-amz-server-side-encryption-customer-algorithm header.
     */
    sseCustomerKey?: string;
    /**
     * Specifies the 128-bit MD5 digest of the encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error.
     */
    sseCustomerKeyMD5?: string;
    /**
     * Specifies the AWS KMS key ID (Key ID, Key ARN, or Key Alias) to use for object encryption. If the KMS key doesn't exist in the same account that's issuing the command, you must use the full Key ARN not the Key ID.

    General purpose buckets - If you specify x-amz-server-side-encryption with aws:kms or aws:kms:dsse, this header specifies the ID (Key ID, Key ARN, or Key Alias) of the AWS KMS key to use. If you specify x-amz-server-side-encryption:aws:kms or x-amz-server-side-encryption:aws:kms:dsse, but do not provide x-amz-server-side-encryption-aws-kms-key-id, Amazon S3 uses the AWS managed key (aws/s3) to protect the data.

    Directory buckets - To encrypt data using SSE-KMS, it's recommended to specify the x-amz-server-side-encryption header to aws:kms. Then, the x-amz-server-side-encryption-aws-kms-key-id header implicitly uses the bucket's default KMS customer managed key ID. If you want to explicitly set the x-amz-server-side-encryption-aws-kms-key-id header, it must match the bucket's default customer managed key (using key ID or ARN, not alias). Your SSE-KMS configuration can only support 1 customer managed key per directory bucket's lifetime. The AWS managed key (aws/s3) isn't supported. Incorrect key specification results in an HTTP 400 Bad Request error.
     */
    sseKMSKeyId?: string;
    /**
     * Specifies the AWS KMS Encryption Context as an additional encryption context to use for object encryption. The value of this header is a Base64 encoded string of a UTF-8 encoded JSON, which contains the encryption context as key-value pairs. This value is stored as object metadata and automatically gets passed on to AWS KMS for future GetObject operations on this object.

    General purpose buckets - This value must be explicitly added during CopyObject operations if you want an additional encryption context for your object.

    Directory buckets - You can optionally provide an explicit encryption context value. The value must match the default encryption context - the bucket Amazon Resource Name (ARN). An additional encryption context value is not supported.
     */
    sseKMSEncryptionContext?: string;
    /**
     * Specifies whether Amazon S3 should use an S3 Bucket Key for object encryption with server-side encryption using AWS Key Management Service (AWS KMS) keys (SSE-KMS).

    General purpose buckets - Setting this header to true causes Amazon S3 to use an S3 Bucket Key for object encryption with SSE-KMS. Also, specifying this header with a PUT action doesn't affect bucket-level settings for S3 Bucket Key.

    Directory buckets - S3 Bucket Keys are always enabled for GET and PUT operations in a directory bucket and can’t be disabled. S3 Bucket Keys aren't supported, when you copy SSE-KMS encrypted objects from general purpose buckets to directory buckets, from directory buckets to general purpose buckets, or between directory buckets, through CopyObject, UploadPartCopy, the Copy operation in Batch Operations, or the import jobs. In this case, Amazon S3 makes a call to AWS KMS every time a copy request is made for a KMS-encrypted object.
     */
    bucketKeyEnabled?: boolean;
    /**
     * Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for corresponding charges to copy the object.
     */
    requestPayer?: 'requester';
    /**
     * The tag-set for the object. The tag-set must be encoded as URL Query parameters. (For example, "Key1=Value1")
     */
    tagging?: string;
    /**
     * The Object Lock mode that you want to apply to this object.
     */
    objectLockMode?: 'GOVERNANCE' | 'COMPLIANCE';
    /**
     * The date and time when you want this object's Object Lock to expire. Must be formatted as a timestamp parameter.
     */
    objectLockRetainUntilDate?: string;
    /**
     * Specifies whether a legal hold will be applied to this object.
     */
    objectLockLegalHoldStatus?: 'ON' | 'OFF';
    /**
     * The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
     */
    expectedBucketOwner?: string;
}
export declare type PutS3ObjectResponseOK = undefined;
export declare type PutS3ObjectResponseError = undefined;
//# sourceMappingURL=object.d.ts.map